import { ComponentController, ComponentInstance } from 'maverick.js/element';
import { FullscreenController } from '../../../foundation/fullscreen/controller';
import { ScreenOrientationController } from '../../../foundation/orientation/controller';
import { Queue } from '../../../foundation/queue/queue';
import type { PlayerAPI } from '../../player';
import type { MediaContext } from '../api/context';
import * as RE from '../api/request-events';
import { MediaUserController } from '../user';
import type { MediaStateManager } from './media-state-manager';
export declare class MediaRequestContext {
    _seeking: boolean;
    _looping: boolean;
    _replaying: boolean;
    _queue: Queue<MediaRequestQueueRecord>;
}
export interface MediaRequestQueueRecord {
    audioTrack: RE.MediaAudioTrackChangeRequestEvent;
    load: RE.MediaStartLoadingRequestEvent;
    play: RE.MediaPlayRequestEvent;
    pause: RE.MediaPauseRequestEvent;
    rate: RE.MediaRateChangeRequestEvent;
    volume: RE.MediaVolumeChangeRequestEvent | RE.MediaMuteRequestEvent | RE.MediaUnmuteRequestEvent;
    fullscreen: RE.MediaEnterFullscreenRequestEvent | RE.MediaExitFullscreenRequestEvent;
    seeked: RE.MediaSeekRequestEvent | RE.MediaLiveEdgeRequestEvent;
    seeking: RE.MediaSeekingRequestEvent;
    textTrack: RE.MediaTextTrackChangeRequestEvent;
    quality: RE.MediaQualityChangeRequestEvent;
    pip: RE.MediaEnterPIPRequestEvent | RE.MediaExitPIPRequestEvent;
    userIdle: RE.MediaResumeUserIdleRequestEvent | RE.MediaPauseUserIdleRequestEvent;
}
export type MediaRequestHandler = {
    [Type in keyof RE.MediaRequestEvents]: (event: RE.MediaRequestEvents[Type]) => unknown;
};
/**
 * This class is responsible for listening to media request events and calling the appropriate
 * actions on the current media provider. Do note, actions are queued until a media provider
 * has connected.
 */
export declare class MediaRequestManager extends ComponentController<PlayerAPI> implements MediaRequestHandler {
    private _stateMgr;
    private _request;
    private _media;
    readonly _user: MediaUserController;
    readonly _fullscreen: FullscreenController;
    readonly _orientation: ScreenOrientationController;
    private readonly _store;
    private readonly _provider;
    constructor(instance: ComponentInstance<PlayerAPI>, _stateMgr: MediaStateManager, _request: MediaRequestContext, _media: MediaContext);
    protected onConnect(): void;
    private _handleRequest;
    _play(): Promise<void>;
    _pause(): Promise<void>;
    _seekToLiveEdge(): void;
    private _wasPIPActive;
    _enterFullscreen(target?: RE.MediaFullscreenRequestTarget): Promise<void>;
    _exitFullscreen(target?: RE.MediaFullscreenRequestTarget): Promise<void>;
    _enterPictureInPicture(): Promise<void | PictureInPictureWindow>;
    _exitPictureInPicture(): Promise<void>;
    private _throwIfPIPNotSupported;
    private _onIdleDelayChange;
    private _onFullscreenSupportChange;
    private _onPiPSupportChange;
    ['media-audio-track-change-request'](event: RE.MediaAudioTrackChangeRequestEvent): void;
    ['media-enter-fullscreen-request'](event: RE.MediaEnterFullscreenRequestEvent): Promise<void>;
    ['media-exit-fullscreen-request'](event: RE.MediaExitFullscreenRequestEvent): Promise<void>;
    private _onFullscreenChange;
    private _onFullscreenError;
    ['media-enter-pip-request'](event: RE.MediaEnterPIPRequestEvent): Promise<void>;
    ['media-exit-pip-request'](event: RE.MediaExitPIPRequestEvent): Promise<void>;
    private _onPictureInPictureError;
    ['media-live-edge-request'](event: RE.MediaLiveEdgeRequestEvent): void;
    ['media-loop-request'](): void;
    ['media-pause-request'](event: RE.MediaPauseRequestEvent): Promise<void>;
    ['media-play-request'](event: RE.MediaPlayRequestEvent): Promise<void>;
    ['media-rate-change-request'](event: RE.MediaRateChangeRequestEvent): void;
    ['media-quality-change-request'](event: RE.MediaQualityChangeRequestEvent): void;
    ['media-resume-user-idle-request'](event: RE.MediaResumeUserIdleRequestEvent): void;
    ['media-pause-user-idle-request'](event: RE.MediaPauseUserIdleRequestEvent): void;
    ['media-seek-request'](event: RE.MediaSeekRequestEvent): void;
    ['media-seeking-request'](event: RE.MediaSeekingRequestEvent): void;
    ['media-start-loading'](event: RE.MediaStartLoadingRequestEvent): void;
    ['media-text-track-change-request'](event: RE.MediaTextTrackChangeRequestEvent): void;
    ['media-mute-request'](event: RE.MediaMuteRequestEvent): void;
    ['media-unmute-request'](event: RE.MediaUnmuteRequestEvent): void;
    ['media-volume-change-request'](event: RE.MediaVolumeChangeRequestEvent): void;
}
