import { type HTMLCustomElement } from 'maverick.js/element';
import { type MediaContext } from '../../core/api/context';
import type { MediaKeyShortcut } from '../../core/keyboard/types';
import { ToggleButton, type ToggleButtonAPI } from './toggle-button';
declare global {
    interface MaverickElements {
        'media-caption-button': MediaCaptionButtonElement;
    }
}
/**
 * A button for toggling the showing state of the captions.
 *
 * @docs {@link https://www.vidstack.io/docs/player/components/buttons/caption-button}
 * @slot on - Used to override the default caption on icon.
 * @slot off - Used to override the default caption off icon.
 * @example
 * ```html
 * <media-caption-button></media-caption-button>
 * ```
 */
export declare class CaptionButton extends ToggleButton {
    static el: import("maverick.js/element").CustomElementDefinition<CaptionButtonAPI>;
    protected _media: MediaContext;
    protected _keyShortcut: MediaKeyShortcut;
    protected onAttach(el: HTMLElement): void;
    protected _onPress(event: Event): void;
    protected _isPressed(): boolean;
    protected _isHidden(): boolean;
    protected _getLabel(): "Closed-Captions Off" | "Closed-Captions On";
    render(): import("maverick.js").JSX.Element;
}
export interface CaptionButtonAPI extends ToggleButtonAPI {
}
export interface MediaCaptionButtonElement extends HTMLCustomElement<CaptionButton> {
}
