import { ComponentInstance, type HTMLCustomElement } from 'maverick.js/element';
import { type MediaContext } from '../../../core/api/context';
import { MenuItems, type MenuItemsAPI } from '../menu-items';
import { Radio } from '../radio/radio';
import { RadioGroup, type RadioGroupChangeEvent } from '../radio/radio-group';
declare global {
    interface MaverickElements {
        'media-audio-menu-items': MediaAudioMenuItemsElement;
    }
}
/**
 * This component displays menu radio options to the user so they can manually change the current
 * audio track.
 *
 * @docs {@link https://www.vidstack.io/docs/player/components/menu/audio-menu}
 * @example
 * ```html
 * <media-menu>
 *   <media-audio-menu-button label="Audio"></media-audio-menu-button>
 *   <media-audio-menu-items></media-audio-menu-items>
 * </media-menu>
 * ```
 */
export declare class AudioMenuItems extends MenuItems<AudioMenuItemsAPI> {
    static el: import("maverick.js/element").CustomElementDefinition<AudioMenuItemsAPI>;
    static register: (typeof Radio | typeof RadioGroup)[];
    protected _media: MediaContext;
    constructor(instance: ComponentInstance<AudioMenuItemsAPI>);
    protected onConnect(el: HTMLElement): void;
    protected _watchHintText(): void;
    protected _watchControllerDisabled(): void;
    protected _isDisabled(): boolean;
    protected _onChange(event: RadioGroupChangeEvent): void;
    protected _getValue(): string;
    protected _getOptions(): {
        value: string;
        content: () => import("maverick.js").JSX.Element;
    }[];
    render(): import("maverick.js").JSX.Element;
}
export interface AudioMenuItemsAPI extends MenuItemsAPI {
    props: AudioMenuItemsProps;
}
export interface AudioMenuItemsProps {
    /** The text to display when the are no audio tracks. */
    emptyLabel: string;
    radioGroupClass: string | null;
    radioClass: string | null;
    radioCheckClass: string | null;
}
export interface MediaAudioMenuItemsElement extends HTMLCustomElement<AudioMenuItems> {
}
