import { ComponentInstance, type HTMLCustomElement } from 'maverick.js/element';
import { type MediaContext } from '../../../core/api/context';
import { MenuItems, type MenuItemsAPI } from '../menu-items';
import { Radio } from '../radio/radio';
import { RadioGroup, type RadioGroupChangeEvent } from '../radio/radio-group';
declare global {
    interface MaverickElements {
        'media-captions-menu-items': MediaCaptionsMenuItemsElement;
    }
}
/**
 * This component displays menu radio options to the user so they can manually change the current
 * captions/subtitles track.
 *
 * @docs {@link https://www.vidstack.io/docs/player/components/menu/captions-menu-items}
 * @example
 * ```html
 * <media-menu>
 *   <media-captions-menu-button label="Captions"></media-captions-menu-button>
 *   <media-captions-menu-items></media-captions-menu-items>
 * </media-menu>
 * ```
 */
export declare class CaptionsMenuItems extends MenuItems<CaptionsMenuItemsAPI> {
    static el: import("maverick.js/element").CustomElementDefinition<CaptionsMenuItemsAPI>;
    static register: (typeof Radio | typeof RadioGroup)[];
    protected _media: MediaContext;
    constructor(instance: ComponentInstance<CaptionsMenuItemsAPI>);
    protected onConnect(el: HTMLElement): void;
    protected _watchHintText(): void;
    protected _watchControllerDisabled(): void;
    protected _isDisabled(): boolean;
    protected _onChange(event: RadioGroupChangeEvent): void;
    protected _getValue(): string;
    protected _getOptions(): {
        value: string;
        content: () => import("maverick.js").JSX.Element;
    }[];
    render(): import("maverick.js").JSX.Element;
}
export interface CaptionsMenuItemsAPI extends MenuItemsAPI {
    props: CaptionsMenuItemsProps;
}
export interface CaptionsMenuItemsProps {
    /** The text to display when the captions are turned off. */
    offLabel: string;
    radioGroupClass: string | null;
    radioClass: string | null;
    radioCheckClass: string | null;
}
export interface MediaCaptionsMenuItemsElement extends HTMLCustomElement<CaptionsMenuItems> {
}
