import { ComponentInstance, type HTMLCustomElement } from 'maverick.js/element';
import { type MediaContext } from '../../../core/api/context';
import { MenuItems, type MenuItemsAPI } from '../menu-items';
import { Radio } from '../radio/radio';
import { RadioGroup, type RadioGroupChangeEvent } from '../radio/radio-group';
declare global {
    interface MaverickElements {
        'media-playback-rate-menu-items': MediaPlaybackRateMenuItemsElement;
    }
}
/**
 * This component displays menu radio options to the user so they can manually change the current
 * playback speed.
 *
 * @docs {@link https://www.vidstack.io/docs/player/components/menu/playback-rate-menu}
 * @example
 * ```html
 * <media-menu>
 *   <media-playback-rate-menu-button label="Speed"></media-playback-rate-menu-button>
 *   <media-playback-rate-menu-items></media-playback-rate-menu-items>
 * </media-menu>
 * ```
 */
export declare class PlaybackRateMenuItems extends MenuItems<PlaybackRateMenuAPI> {
    static el: import("maverick.js/element").CustomElementDefinition<PlaybackRateMenuAPI>;
    static register: (typeof Radio | typeof RadioGroup)[];
    protected _media: MediaContext;
    constructor(instance: ComponentInstance<PlaybackRateMenuAPI>);
    protected onConnect(el: HTMLElement): void;
    protected _watchHintText(): void;
    protected _onChange(event: RadioGroupChangeEvent): void;
    protected _getValue(): string;
    protected _getOptions(): {
        value: string;
        content: () => import("maverick.js").JSX.Element;
    }[];
    render(): import("maverick.js").JSX.Element;
}
export interface PlaybackRateMenuAPI extends MenuItemsAPI {
    props: PlaybackRateMenuProps;
}
export interface PlaybackRateMenuProps {
    /** The playback rate options to be displayed. */
    rates: number[];
    /** The text to display for normal speed (i.e., playback rate of 1). */
    normalLabel: string;
    radioGroupClass: string | null;
    radioClass: string | null;
    radioCheckClass: string | null;
}
export interface MediaPlaybackRateMenuItemsElement extends HTMLCustomElement<PlaybackRateMenuItems> {
}
