import { ComponentInstance, type HTMLCustomElement } from 'maverick.js/element';
import { type MediaContext } from '../../../core/api/context';
import type { VideoQuality } from '../../../core/quality/video-quality';
import { MenuItems, type MenuItemsAPI } from '../menu-items';
import { Radio } from '../radio/radio';
import { RadioGroup, type RadioGroupChangeEvent } from '../radio/radio-group';
declare global {
    interface MaverickElements {
        'media-quality-menu-items': MediaQualityMenuItemsElement;
    }
}
/**
 * This component displays menu radio options to the user so they can manually change the current
 * playback quality.
 *
 * @docs {@link https://www.vidstack.io/docs/player/components/menu/quality-menu}
 * @example
 * ```html
 * <media-menu>
 *   <media-quality-menu-button label="Quality"></media-quality-menu-button>
 *   <media-quality-menu-items></media-quality-menu-items>
 * </media-menu>
 * ```
 */
export declare class QualityMenuItems extends MenuItems<QualityMenuItemsAPI> {
    static el: import("maverick.js/element").CustomElementDefinition<QualityMenuItemsAPI>;
    static register: (typeof Radio | typeof RadioGroup)[];
    protected _media: MediaContext;
    protected _sortedQualities: import("maverick.js").ReadSignal<VideoQuality[]>;
    constructor(instance: ComponentInstance<QualityMenuItemsAPI>);
    protected onConnect(el: HTMLElement): void;
    protected _watchHintText(): void;
    protected _watchControllerDisabled(): void;
    protected _isDisabled(): boolean;
    protected _onChange(event: RadioGroupChangeEvent): void;
    protected _getValue(): string;
    protected _getQualityId(quality: VideoQuality): string;
    protected _getOptions(): {
        value: string;
        content: () => import("maverick.js").JSX.Element;
    }[];
    render(): import("maverick.js").JSX.Element;
}
export interface QualityMenuItemsAPI extends MenuItemsAPI {
    props: QualityMenuItemsProps;
}
export interface QualityMenuItemsProps {
    /** The text to display for the auto quality radio option. */
    autoLabel: string;
    /** Whether the bitrate should _not_ be displayed next to each quality radio option. */
    hideBitrate: boolean;
    radioGroupClass: string | null;
    radioClass: string | null;
    radioCheckClass: string | null;
}
export interface MediaQualityMenuItemsElement extends HTMLCustomElement<QualityMenuItems> {
}
